@@ -1,5 +1,6 @@
 import errno
 from fcntl import LOCK_EX, LOCK_NB, LOCK_SH, LOCK_UN
+from itertools import takewhile, dropwhile
 import logging
 import os
 import random
@@ -68,7 +69,12 @@ class Docker(Containerizer, _Struct):
             os.chdir(launchy.directory)
         # TODO: if launchy.user:
         #           os.seteuid(launchy.user)
-        url, options = self.container_settings.override(*launchy.container)
+        url, options = launchy.container
+        options, trailing_argv = split_on(options, "//")
+        url, options = self.container_settings.override(url, options)
+
+        true_argv = launchy.argv if trailing_argv is None else trailing_argv
+
         image = self.determine_image(url, launchy)
         log.info("image  = %s", image)
         run_options += ["--sig-proxy"]
@@ -120,7 +126,9 @@ class Docker(Containerizer, _Struct):
         else:
             env += mesos_env() + [("MESOS_DIRECTORY", self.workdir)]
 
-        runner_argv = deimos.docker.run(run_options, image, launchy.argv,
+        self.place_dockercfg()
+
+        runner_argv = deimos.docker.run(run_options, image, true_argv,
                                         env=env, ports=launchy.ports,
                                         cpus=cpus, mems=mems)
 
@@ -319,11 +327,23 @@ class Docker(Containerizer, _Struct):
             if not launchy.needs_observer:
                 opts["account"] = opts["account_libmesos"]
             del opts["account_libmesos"]
+        if "dockercfg" in opts:
+            del opts["dockercfg"]
         return deimos.docker.matching_image_for_host(**opts)
 
+    def place_dockercfg(self):
+        dockercfg = self.index_settings.dockercfg
+        if dockercfg is not None:
+            log.info("Copying to .dockercfg: %s" % dockercfg)
+            Run()(["cp", dockercfg, ".dockercfg"])
+
 def url_to_image(url):
     pre, image = re.split(r"^docker:///?", url)
     if pre != "":
         raise Err("URL '%s' is not a valid docker:// URL!" % url)
     return image
 
+def split_on(iterable, element):
+    preceding = list(takewhile(lambda _: _ != element, iterable))
+    following = list(dropwhile(lambda _: _ != element, iterable))
+    return preceding, (following[1:] if len(following) > 0 else None)
